[PATCH] D46463: [sanitizer] On RTEMS, avoid recursion when reporting Mmap failure

Walter Lee via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Fri May 4 13:50:01 PDT 2018


waltl created this revision.
waltl added reviewers: vitalybuka, eugenis, alekseyshl.
Herald added a subscriber: kubamracek.

Repository:
  rL LLVM

https://reviews.llvm.org/D46463

Files:
  compiler-rt/lib/sanitizer_common/sanitizer_common.cc


Index: compiler-rt/lib/sanitizer_common/sanitizer_common.cc
===================================================================
--- compiler-rt/lib/sanitizer_common/sanitizer_common.cc
+++ compiler-rt/lib/sanitizer_common/sanitizer_common.cc
@@ -38,9 +38,10 @@
                                       const char *mmap_type, error_t err,
                                       bool raw_report) {
   static int recursion_count;
-  if (raw_report || recursion_count) {
-    // If raw report is requested or we went into recursion, just die.
-    // The Report() and CHECK calls below may call mmap recursively and fail.
+  if (SANITIZER_RTEMS || raw_report || recursion_count) {
+    // If we are on RTEMS or raw report is requested or we went into recursion,
+    // just die.  The Report() and CHECK calls below may call mmap recursively
+    // and fail.
     RawWrite("ERROR: Failed to mmap\n");
     Die();
   }


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D46463.145280.patch
Type: text/x-patch
Size: 913 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20180504/09964270/attachment.bin>


More information about the llvm-commits mailing list